=====================================
 |PD| -- a distributed issue tracker
=====================================

.. toctree::
   :maxdepth: 2

   readme
   intro
   guide
   custom
   plugin
   devel
   faq
   credits

Indices and tables
==================

* :ref:`genindex`
* :ref:`search`
